Gerrit Dashboards
=================

Gerrit Dashboard Creator creates custom URLs for Gerrit dashboards.
It helps reviewer easily to look the reviews.

- `Tacker master branch reviews <https://review.opendev.org/#/dashboard/?foreach=%28+project%3Aopenstack%2Ftacker+OR%0Aproject%3Aopenstack%2Ftacker%2Dspecs+OR%0Aproject%3Aopenstack%2Ftacker%2Dhorizon+OR%0Aproject%3Aopenstack%2Fpython%2Dtackerclient+%29%0Astatus%3Aopen%0ANOT+owner%3Aself%0ANOT+label%3AWorkflow%3C%3D%2D1%0Alabel%3AVerified%3E%3D1%2Czuul%0ANOT+reviewedby%3Aself&title=Tacker+Review+Inbox&Proposal+Bot+Proposals=owner%3A%22OpenStack+Proposal+Bot+%3Copenstack%2Dinfra%40lists.openstack.org%3E%22&Needs+final+%2B2=label%3ACode%2DReview%3E%3D2+NOT+label%3ACode%2DReview%3C%3D%2D1+NOT+label%3AVerified%3C%3D%2D1+NOT+label%3ACode%2DReview%3C%3D%2D1%2Cself+NOT+label%3ACode%2DReview%3E%3D1%2Cself+NOT+owner%3Aself+limit%3A10&Needs+Feedback+%28Changes+older+than+5+days+that+have+not+been+reviewed+by+anyone%29=NOT+label%3ACode%2DReview%3C%3D%2D1+NOT+label%3ACode%2DReview%3E%3D1+NOT+label%3AVerified%3C%3D%2D1+NOT+owner%3Aself+age%3A5d&You+are+a+reviewer%2C+but+haven%27t+voted+in+the+current+revision=NOT+label%3ACode%2DReview%3C%3D%2D1%2Cself+NOT+label%3ACode%2DReview%3E%3D1%2Cself+reviewer%3Aself+NOT+owner%3Aself+limit%3A10&Passed+Zuul%2C+No+Negative+Feedback=label%3ACode%2DReview%3E%3D1+NOT+label%3ACode%2DReview%3C%3D%2D1+AND+NOT+label%3AVerified%3C%3D%2D1+NOT+owner%3Aself+NOT+reviewer%3Aself+limit%3A10&Negative+Feedback=label%3ACode%2DReview%3C%3D%2D1+limit%3A10&Maybe+Review%3F=NOT+owner%3Aself+NOT+reviewer%3Aself+limit%3A10&Wayward+Changes+%28Changes+with+no+code+review+in+the+last+2days%29=NOT+label%3ACode%2DReview%3C%3D%2D1+NOT+label%3ACode%2DReview%3E%3D1+age%3A2d>`_

These dashboard links can be generated by `Gerrit Dashboard Creator`_.
Useful dashboard definitions are found in ``dashboards`` directory.

.. _Gerrit Dashboard Creator: https://opendev.org/x/gerrit-dash-creator
